diff --git a/src/Microsoft.PowerShell.Commands.Management/commands/management/Computer.cs b/src/Microsoft.PowerShell.Commands.Management/commands/management/Computer.cs
index 2203c920c1..3b791d37a1 100644
--- a/src/Microsoft.PowerShell.Commands.Management/commands/management/Computer.cs
+++ b/src/Microsoft.PowerShell.Commands.Management/commands/management/Computer.cs
@@ -2054,25 +2054,6 @@ $result
return !allDigits;
}
- ///
- /// System Restore APIs are not supported on the ARM platform. Skip the system restore operation is necessary.
- ///
- ///
- ///
- internal static bool SkipSystemRestoreOperationForARMPlatform(PSCmdlet cmdlet)
- {
- bool retValue = false;
- if (PsUtils.IsRunningOnProcessorArchitectureARM())
- {
- var ex = new InvalidOperationException(ComputerResources.SystemRestoreNotSupported);
- var er = new ErrorRecord(ex, "SystemRestoreNotSupported", ErrorCategory.InvalidOperation, null);
- cmdlet.WriteError(er);
- retValue = true;
- }
-
- return retValue;
- }
-
///
/// Invokes the Win32Shutdown command on provided target computer using WSMan
/// over a CIMSession. The flags parameter determines the type of shutdown operation
diff --git a/src/System.Management.Automation/engine/parser/Parser.cs b/src/System.Management.Automation/engine/parser/Parser.cs
index 464231c040..8664da5194 100644
--- a/src/System.Management.Automation/engine/parser/Parser.cs
+++ b/src/System.Management.Automation/engine/parser/Parser.cs
@@ -3004,8 +3004,8 @@ namespace System.Management.Automation.Language
dropIntoDebugger: true);
}
- // Configuration is not supported on ARM64
- if (PsUtils.IsRunningOnProcessorArchitectureARM())
+ // Configuration is not supported for ARM or ARM64 process architecture.
+ if (PsUtils.IsRunningOnProcessArchitectureARM())
{
ReportError(
configurationToken.Extent,
diff --git a/src/System.Management.Automation/utils/PsUtils.cs b/src/System.Management.Automation/utils/PsUtils.cs
index 53809e586a..d404581bf1 100644
--- a/src/System.Management.Automation/utils/PsUtils.cs
+++ b/src/System.Management.Automation/utils/PsUtils.cs
@@ -74,12 +74,12 @@ namespace System.Management.Automation
}
///
/// Return true/false to indicate whether the processor architecture is ARM.
///
///
- internal static bool IsRunningOnProcessorArchitectureARM()
+ internal static bool IsRunningOnProcessArchitectureARM()
{
- Architecture arch = RuntimeInformation.OSArchitecture;
+ Architecture arch = RuntimeInformation.ProcessArchitecture;
return arch == Architecture.Arm || arch == Architecture.Arm64;
}
@@ -74,12 +74,12 @@ namespace System.Management.Automation
}
///
- /// Return true/false to indicate whether the processor architecture is ARM.
+ /// Return true/false to indicate whether the process architecture is ARM.
///
///